﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace CodeRetrieverDataflow
{
    public partial class Form1 : Form
    {
        /*
        #
        # This is an object for holding dataflow information relating to a given mnemonic value.
        #
        # Mnemonic: Holds the value of the mnemonic string. Used in retrieving the dataflow code.
        # DataFlowCode: Holds the retrieved data flow code.
        # BoxWidth: Holds the char width of the box in a list.
        # BoxNum: A list of the box numbers associated with the data flow code.
        # NewBoxNum: A list for the new box numbers.
        # BoxDesc: A list of box descriptions for each box.
        #
        */
        public class DataFlow
        {
            // Constructor:
            public DataFlow(string mnemonic)
            {
                Mnemonic = mnemonic;
                BoxWidth = new List<string>();
                BoxNum = new List<string>();
                NewBoxNum = new List<string>();
                BoxDesc = new List<string>();
            }

            // Properties:
            public string Mnemonic { get; set; }
            public string DataFlowCode { get; set; }
            public List<string> BoxWidth { get; set; }
            public List<string> BoxNum { get; set; }
            public List<string> NewBoxNum { get; set; }
            public List<string> BoxDesc { get; set; }
        }

        /*
        #
        # Box: The actual box number.
        # Width: The maximum number of characters that the box can hold [for truncation].
        #
        # Width is stored as a string and will equal "MAN" to indicate the width will need to be set manually or "NO XML" 
        # to indicate the box information was obtained from the .RBW file so width cannot be determined.
        #
        */
        public class FormBox
        {
            // Constructor:
            public FormBox(string box, string width)
            {
                Box = box;
                Width = width;
            }

            // Properties:
            public string Box { get; set; }
            public string Width { get; set; }
        }

        /*
        # IfStr: Holds the 'if (..)' portion of the conditional expression.
        # ElseStr: Holds the information pertaining to the 'else' portion of the conditional expression.
        #
        # Both class members are context specific.
        */
        public class CondExp
        {
            // Constructor:
            public CondExp(string ifStr, string elseStr)
            {
                IfStr = ifStr;
                ElseStr = elseStr;
            }

            // Properties:
            public string IfStr { get; set; }
            public string ElseStr { get; set; }
        }
    }
}